@@ -1,4 +1,4 @@
-import featuretools as ft
+import featuretools as f
 import numpy as np
 import pandas as pd
 from dateutil import parser
@@ -272,7 +272,7 @@ def dfs(spark: SparkSession,
                              es_id: str,
                              entities: list,
                              relationships: list,
-                             interestings: list):
+                             interestings: list=None):
         #nonlocal out
         list_iter = list(iterator)
         print('in single')
@@ -280,7 +280,7 @@ def dfs(spark: SparkSession,
         if len(list_iter) > 0:
             data = pd.DataFrame(list_iter, columns=all_columns)
 
-            es = ft.EntitySet(id=es_id)
+            es = f.EntitySet(id=es_id)
             for entity in entities:
                 columns = entity.columns
 
@@ -302,18 +302,19 @@ def dfs(spark: SparkSession,
                 parent_col = EntitySpark.recover_col_name(parent_entity, relationship.parent_variable.column_name)
                 child_entity = relationship.child_variable.entity_id
                 child_col = EntitySpark.recover_col_name(child_entity, relationship.child_variable.column_name)
-                es.add_relationship(ft.Relationship(es[parent_entity][parent_col],
+                es.add_relationship(f.Relationship(es[parent_entity][parent_col],
                                                     es[child_entity][child_col]))
-            
-            for interesting in interestings:
-                entityid = interesting.entity_id 
-                col = interesting.column
-                intr_vals = interesting.vals
-                es[entityid][col].interesting_values = intr_vals
+            if interestings:
+                for interesting in interestings:
+                    entityid = interesting.entity_id 
+                    col = interesting.column
+                    intr_vals = interesting.vals
+                    es[entityid][col].interesting_values = intr_vals
 
-            feature_matrix, feature_dfs = ft.dfs(entityset=es,
+            feature_matrix, feature_dfs = f.dfs(entityset=es,
                                                  agg_primitives=agg_primitives,
                                                  trans_primitives=trans_primitives,
+                                                 where_primitives=where_primitives,
                                                  target_entity=target_entity,
                                                  cutoff_time=cutoff_time,
                                                  cutoff_time_in_index=False,
@@ -336,8 +337,8 @@ def dfs(spark: SparkSession,
             for i in range(feature_matrix.shape[0]):
                 row_res = {}
                 for col in columns:
-                    value = feature_matrix.ix[i, col]
-
+                    value = feature_matrix.loc[i, col]
+                    #value 
                     # convert Numpy types to Python types, otherwise it cannot be converted
                     # to Spark DataFrame.
                     if isinstance(value, np.int64):
@@ -361,10 +362,11 @@ def dfs(spark: SparkSession,
     print('enetities are',entities)
     relationships = entityset.relationships
     interestings = entityset.interestings
+    print('interestings are',interestings)
     rdd = repartitioned.rdd.mapPartitions(lambda iteration: run_single_partition(iteration, all_columns,
                                                                                  es_id, entities, relationships,interestings))
 
-    
+    print('before rdd')
     # using Rdd of Rows
     res_df = rdd.map(lambda x: Row(**x)).toDF()
-    return res_df
\ No newline at end of file
+    return res_df
